@@ -42,12 +42,8 @@
 #include <limits.h>
 #include <string.h>
 #include <sys/types.h>
-#ifdef HAVE_MACH_BOOLEAN_H
-#include <mach/boolean.h>
-#endif
-#ifdef HAVE_UVM_UVM_PARAM_H
-#include <uvm/uvm_param.h>
-#endif
+#include <stdint.h>
+#include <stdbool.h>
 
 #include "assert.h"
 #include "system/Mem.h"
@@ -76,7 +72,7 @@
 #include "NumberFormatException.h"
 
 
-/* ------------------------------------------ General Purpose value macros */
+/* ------------------------------------------------------- Constant macros */
 
 
 /**
@@ -85,15 +81,6 @@
 #define STRLEN 256
 
 
-/* ---------------------------------------------------------- Build macros */
-
-
-/* Mask out GCC __attribute__ extension for non-gcc compilers. */
-#ifndef __GNUC__
-#define __attribute__(x)
-#endif
-
-
 /* ------------------------------------------------------ Type definitions */
 
 
@@ -105,28 +92,6 @@ typedef unsigned char uchar_t;
 #endif
 
 
-/**
- * The internal 32 bits integer type
- */
-#ifndef HAVE_UINT32_T
-typedef unsigned int uint32_t;
-#endif
-
-
-/**
- * The internal boolean integer type
- */
-#ifndef HAVE_BOOLEAN_T
-typedef enum {
-        false = 0,
-        true
-} __attribute__((__packed__)) boolean_t;
-#else
-#define false 0
-#define true  1
-#endif
-
-
 #endif
 
 
