@@ -97,7 +97,7 @@ static struct {
 /* ----------------------------------------------------------------- Private */
 
 
-static bool _getDummyDiskActivity(void *_inf) {
+static bool _getDummyDiskActivity(__attribute__ ((unused)) void *_inf) {
         return true;
 }
 
@@ -114,7 +114,7 @@ static bool _getZfsDiskActivity(void *_inf) {
                 if (nvlist_lookup_nvlist(zpoolConfig, ZPOOL_CONFIG_VDEV_TREE, &zpoolVdevTree) == 0) {
                         vdev_stat_t *zpoolStatistics = NULL;
                         uint_t zpoolStatisticsCount = 0;
-                        if (nvlist_lookup_uint64_array(zpoolVdevTree, ZPOOL_CONFIG_VDEV_STATS, (unsigned long long **)&zpoolStatistics, &zpoolStatisticsCount) == 0) {
+                        if (nvlist_lookup_uint64_array(zpoolVdevTree, ZPOOL_CONFIG_VDEV_STATS, (uint64_t **)&zpoolStatistics, &zpoolStatisticsCount) == 0) {
                                 //FIXME: if the zpool state has error, trigger the fs event, can also report number of read/write/checksum errors (see vdev_stat_t in /usr/include/sys/fs/zfs.h)
                                 DEBUG("ZFS pool '%s' state: %s\n", inf->filesystem->object.key, zpool_state_to_name(zpoolStatistics->vs_state, zpoolStatistics->vs_aux));
                                 unsigned long long now = Time_milli();
@@ -206,12 +206,8 @@ static bool _setDevice(Info_T inf, const char *path, bool (*compare)(const char
                         strncpy(inf->filesystem->object.mountpoint, mnt.mnt_mountp, sizeof(inf->filesystem->object.mountpoint) - 1);
                         strncpy(inf->filesystem->object.type, mnt.mnt_fstype, sizeof(inf->filesystem->object.type) - 1);
                         inf->filesystem->object.getDiskUsage = _getDiskUsage; // The disk usage method is common for all filesystem types
-                        if (! IS(mnt.mnt_mntopts, inf->filesystem->flags)) {
-                                if (*(inf->filesystem->flags)) {
-                                        inf->filesystem->flagsChanged = true;
-                                }
-                                snprintf(inf->filesystem->flags, sizeof(inf->filesystem->flags), "%s", mnt.mnt_mntopts);
-                        }
+                        Util_swapFilesystemFlags(&(inf->filesystem->flags));
+                        snprintf(inf->filesystem->flags.current, sizeof(inf->filesystem->flags.value[0]), "%s", mnt.mnt_mntopts);
                         if (Str_startsWith(mnt.mnt_fstype, MNTTYPE_NFS)) {
                                 strncpy(inf->filesystem->object.module, "nfs", sizeof(inf->filesystem->object.module) - 1);
                                 snprintf(inf->filesystem->object.key, sizeof(inf->filesystem->object.key), "nfs%d", mnt.mnt_minor);
@@ -221,7 +217,10 @@ static bool _setDevice(Info_T inf, const char *path, bool (*compare)(const char
                         } else if (IS(mnt.mnt_fstype, MNTTYPE_ZFS)) {
                                 strncpy(inf->filesystem->object.module, "zfs", sizeof(inf->filesystem->object.module) - 1);
                                 char *slash = strchr(mnt.mnt_special, '/');
-                                strncpy(inf->filesystem->object.key, mnt.mnt_special, slash ? slash - mnt.mnt_special : sizeof(inf->filesystem->object.key) - 1);
+                                if (slash)
+                                        strncpy(inf->filesystem->object.key, mnt.mnt_special, slash - mnt.mnt_special);
+                                else
+                                        strncpy(inf->filesystem->object.key, mnt.mnt_special, sizeof(inf->filesystem->object.key) - 1);
                                 inf->filesystem->object.getDiskActivity = _getZfsDiskActivity;
                                 rv = true;
                         } else if (IS(mnt.mnt_fstype, MNTTYPE_UFS)) {
