@@ -51,6 +51,7 @@ static void _gcfilesystem(FileSystem_T *);
 static void _gcicmp(Icmp_T *);
 static void _gcpql(Resource_T *);
 static void _gcptl(Timestamp_T *);
+static void _gcuptimelist(Uptime_T *);
 static void _gcparl(ActionRate_T *);
 static void _gc_action(Action_T *);
 static void _gc_eventaction(EventAction_T *);
@@ -208,6 +209,8 @@ static void _gc_service(Service_T *s) {
                 _gcpql(&(*s)->resourcelist);
         if ((*s)->timestamplist)
                 _gcptl(&(*s)->timestamplist);
+        if ((*s)->uptimelist)
+                _gcuptimelist(&(*s)->uptimelist);
         if ((*s)->actionratelist)
                 _gcparl(&(*s)->actionratelist);
         if ((*s)->sizelist)
@@ -412,6 +415,10 @@ static void _gcportlist(Port_T *p) {
                 FREE((*p)->parameters.mysql.username);
                 FREE((*p)->parameters.mysql.password);
                 FREE((*p)->parameters.mysql.rsaChecksum);
+        } else if ((*p)->protocol->check == check_pgsql) {
+                FREE((*p)->parameters.postgresql.username);
+                FREE((*p)->parameters.postgresql.password);
+                FREE((*p)->parameters.postgresql.database);
         } else if ((*p)->protocol->check == check_sip) {
                 FREE((*p)->parameters.sip.target);
         } else if ((*p)->protocol->check == check_smtp) {
@@ -473,6 +480,16 @@ static void _gcptl(Timestamp_T *p) {
 }
 
 
+static void _gcuptimelist(Uptime_T *u) {
+        ASSERT(u);
+        if ((*u)->next)
+                _gcuptimelist(&(*u)->next);
+        if ((*u)->action)
+                _gc_eventaction(&(*u)->action);
+        FREE(*u);
+}
+
+
 static void _gcparl(ActionRate_T *ar) {
         ASSERT(ar);
         if ((*ar)->next)
