@@ -154,7 +154,7 @@ bool Util_isurlsafe(const char *url);
  * @param isParameterValue true if the string is url parameter value
  * @return the escaped string
  */
-char *Util_urlEncode(char *string, bool isParameterValue);
+char *Util_urlEncode(const char *string, bool isParameterValue);
 
 
 /**
@@ -295,12 +295,13 @@ StringBuffer_T Util_printEventratio(Action_T action, StringBuffer_T buf);
  * Append a rule description to the given StringBuffer. The description
  * consists of the formatted string given by the rule argument and constant
  * part which describes rule actions based on the action argument.
+ * @param inverse Inverse test flag
  * @param buf StringBuffer
  * @param action An EventAction object
  * @param rule Rule description
  * @return StringBuffer reference
  */
-StringBuffer_T Util_printRule(StringBuffer_T buf, EventAction_T action, const char *rule, ...) __attribute__((format (printf, 3, 4)));
+StringBuffer_T Util_printRule(bool inverse, StringBuffer_T buf, EventAction_T action, const char *rule, ...) __attribute__((format (printf, 4, 5)));
 
 
 /**
@@ -348,11 +349,18 @@ char *Util_commandDescription(command_t command, char s[STRLEN]);
 
 /**
  * Return string presentation of TIME_* unit
- *  @param time The TIME_* unit (see monit.h)
- *  @return string
+ * @param time The TIME_* unit (see monit.h)
+ * @return string
  */
 const char *Util_timestr(int time);
 
 
+/**
+ * Swap previous and current filesystem flags in the ringbuffer
+ * @flags Filesystem flags
+ */
+void Util_swapFilesystemFlags(FilesystemFlags_T flags);
+
+
 #endif
 
